# Fact Sheet Subtype Management
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/fact-sheet-subtype-management#overview)
  * [Creating Custom Fact Sheet Subtypes](https://help.sap.com/docs/leanix/ea/fact-sheet-subtype-management#creating-custom-fact-sheet-subtypes)
  * [Creating Attributes Specific to Subtypes](https://help.sap.com/docs/leanix/ea/fact-sheet-subtype-management#creating-attributes-specific-to-subtypes)
  * [Limiting Existing Attributes to Specific Subtypes](https://help.sap.com/docs/leanix/ea/fact-sheet-subtype-management#limiting-existing-attributes-to-specific-subtypes)
  * [Scope of Subtype Management](https://help.sap.com/docs/leanix/ea/fact-sheet-subtype-management#scope-of-subtype-management)


Fact Sheet subtype management enables admins to create subtypes easily and tailor attributes for specific subtypes using conditional attributes.
